import React, { PropsWithChildren, MouseEventHandler, FC } from 'react';
import { AvatarProps } from '@mui/material/Avatar';
import { AvatarGroupProps, BadgeProps, PopoverProps, MenuClasses, MenuListProps as MenuListProps$1, SxProps, Theme, PopoverOrigin, MenuItemClasses, ListItemClasses, ListItemIconClasses, ListItemAvatarClasses, ListItemButtonClasses, ListItemTextClasses, TooltipClasses, PopperProps, TooltipComponentsPropsOverrides, TableRowClasses, TableSortLabelClasses, SelectProps, TabScrollButtonProps, StepIconProps, TypographyOwnProps } from '@mui/material';
import { TransitionProps } from '@mui/material/transitions';
import { ListClasses } from '@mui/material/List';
import { DividerProps } from '@mui/material/Divider';
import { MUIStyledCommonProps, ResponsiveStyleValue, SxProps as SxProps$1, Theme as Theme$1 } from '@mui/system';
import { TableClasses } from '@mui/material/Table';
import { TableBodyClasses } from '@mui/material/TableBody';
import { TableCellClasses, TableCellBaseProps, SortDirection } from '@mui/material/TableCell';
import { TableContainerClasses } from '@mui/material/TableContainer';
import { TableFooterClasses } from '@mui/material/TableFooter';
import { TableHeadClasses } from '@mui/material/TableHead';
import { TablePaginationClasses, LabelDisplayedRowsArgs } from '@mui/material/TablePagination';
import { TablePaginationActionsProps } from '@mui/material/TablePagination/TablePaginationActions';
import { GridProps as GridProps$1 } from '@mui/material/Grid';
import { GridSpacing, GridDirection, GridWrap, GridSize } from '@mui/system/Unstable_Grid';
import { DrawerProps } from '@mui/material/Drawer';
import { StepperClasses, Orientation } from '@mui/material/Stepper';
import { TabsActions, TabsClasses } from '@mui/material/Tabs';
import { TabClasses } from '@mui/material/Tab';
import { StepClasses } from '@mui/material/Step';
import { StepButtonClasses } from '@mui/material/StepButton';
import { StepLabelClasses } from '@mui/material/StepLabel';
import { StepContentClasses } from '@mui/material/StepContent';
import { TypographyClasses, TypographyPropsVariantOverrides } from '@mui/material/Typography';
import { Variant } from '@mui/material/styles/createTypography';
import { OverridableStringUnion } from '@mui/types';
import { AccordionProps } from '@mui/material/Accordion';
import { AccordionDetailsProps } from '@mui/material/AccordionDetails';
import { AccordionSummaryProps } from '@mui/material/AccordionSummary';
import { CardProps } from '@mui/material/Card';
import { CardActionsProps } from '@mui/material/CardActions';
import { CardContentProps } from '@mui/material/CardContent';
import { LinkClasses } from '@mui/material/Link';
import { AppBarProps } from '@mui/material/AppBar';
import { AlertProps } from '@mui/material/Alert';
import { AlertTitleProps } from '@mui/material/AlertTitle';
import { BackdropProps } from '@mui/material/Backdrop';
import { DialogProps } from '@mui/material/Dialog';
import { DialogActionsProps } from '@mui/material/DialogActions';
import { DialogContentProps } from '@mui/material/DialogContent';
import { DialogContentTextProps } from '@mui/material/DialogContentText';
import { DialogTitleProps } from '@mui/material/DialogTitle';
import { ChipProps } from '@mui/material/Chip';
import { BoxProps } from '@mui/material/Box';
import { ToolbarClasses, ToolbarPropsVariantOverrides } from '@mui/material/Toolbar';
import { PaperClasses, PaperPropsVariantOverrides } from '@mui/material/Paper';
import { FormGroupProps } from '@mui/material/FormGroup';
import { FormControlProps } from '@mui/material/FormControl';
import { FormControlLabelProps } from '@mui/material/FormControlLabel';
import { FormHelperTextProps } from '@mui/material/FormHelperText';
import { FormLabelProps } from '@mui/material/FormLabel';
import { CircularProgressClasses, CircularProgressPropsColorOverrides } from '@mui/material/CircularProgress';
import { LinearProgressClasses, LinearProgressPropsColorOverrides } from '@mui/material/LinearProgress';
import * as Icons from '@mui/icons-material';
import { AutocompleteProps } from '@mui/material/Autocomplete';
export { default as Button } from './components/Button/index.mjs';
import { LoadingButtonProps } from '@mui/lab/LoadingButton';
import { IconButtonProps } from '@mui/material/IconButton';
import { ButtonProps } from '@mui/material/Button';
import { ButtonGroupProps } from '@mui/material/ButtonGroup';
import { CheckboxProps } from '@mui/material/Checkbox';
import { FabProps } from '@mui/material/Fab';
import { RadioProps } from '@mui/material/Radio';
import { RadioGroupProps } from '@mui/material/RadioGroup';
import { RatingProps } from '@mui/material/Rating';
import { SelectProps as SelectProps$1 } from '@mui/material/Select';
import { SwitchProps } from '@mui/material/Switch';
import { SliderProps } from '@mui/material/Slider';
import { TextFieldProps } from '@mui/material/TextField';
import { InputAdornmentProps } from '@mui/material/InputAdornment';
import { OutlinedInputProps } from '@mui/material/OutlinedInput';
import { ToggleButtonProps } from '@mui/material/ToggleButton';
import { ToggleButtonGroupProps } from '@mui/material/ToggleButtonGroup';

declare const Avatar: (props: AvatarProps) => React.JSX.Element;

declare const AvatarGroup: (props: AvatarGroupProps) => React.JSX.Element;

declare const Badge: (props: BadgeProps) => React.JSX.Element;

type MenuProps = PropsWithChildren & {
    id?: string;
    /**
   * An HTML element, or a function that returns one.
   * It's used to set the position of the menu.
   */
    anchorEl?: PopoverProps['anchorEl'];
    /**
     * If `true` (Default) will focus the `[role="menu"]` if no focusable child is found. Disabled
     * children are not focusable. If you set this prop to `false` focus will be placed
     * on the parent modal container. This has severe accessibility implications
     * and should only be considered if you manage focus otherwise.
     * @default true
     */
    autoFocus?: boolean;
    /**
     * Menu contents, normally `MenuItem`s.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<MenuClasses>;
    /**
     * When opening the menu will not focus the active item but the `[role="menu"]`
     * unless `autoFocus` is also set to `false`. Not using the default means not
     * following WAI-ARIA authoring practices. Please be considerate about possible
     * accessibility implications.
     * @default false
     */
    disableAutoFocusItem?: boolean;
    /**
     * Props applied to the [`MenuList`](/material-ui/api/menu-list/) element.
     * @default {}
     */
    MenuListProps?: Partial<MenuListProps$1>;
    /**
     * Callback fired when the component requests to be closed.
     *
     * @param {object} event The event source of the callback.
     * @param {string} reason Can be: `"escapeKeyDown"`, `"backdropClick"`, `"tabKeyDown"`.
     */
    onClose?: PopoverProps['onClose'];
    /**
     * If `true`, the component is shown.
     */
    open: boolean;
    /**
     * `classes` prop applied to the [`Popover`](/material-ui/api/popover/) element.
     */
    PopoverClasses?: PopoverProps['classes'];
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The length of the transition in `ms`, or 'auto'
     * @default 'auto'
     */
    transitionDuration?: TransitionProps['timeout'] | 'auto';
    /**
     * Props applied to the transition element.
     * By default, the element is based on this [`Transition`](https://reactcommunity.org/react-transition-group/transition/) component.
     * @default {}
     */
    TransitionProps?: TransitionProps;
    /**
     * The variant to use. Use `menu` to prevent selected items from impacting the initial focus.
     * @default 'selectedMenu'
     */
    variant?: 'menu' | 'selectedMenu';
    onClick?: MouseEventHandler<any>;
    transformOrigin?: PopoverOrigin;
    anchorOrigin?: PopoverOrigin;
    keepMounted?: boolean;
};
declare const Menu: (props: MenuProps) => React.JSX.Element;

type MenuItemProps = PropsWithChildren & {
    key?: string;
    /**
    * If `true`, the list item is focused during the first mount.
    * Focus will also be triggered if the value changes from false to true.
    * @default false
    */
    autoFocus?: boolean;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<MenuItemClasses>;
    /**
     * If `true`, compact vertical padding designed for keyboard and mouse input is used.
     * The prop defaults to the value inherited from the parent Menu component.
     * @default false
     */
    dense?: boolean;
    /**
     * If `true`, the component is disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * If `true`, the left and right padding is removed.
     * @default false
     */
    disableGutters?: boolean;
    /**
     * If `true`, a 1px light border is added to the bottom of the menu item.
     * @default false
     */
    divider?: boolean;
    /**
     * If `true`, the component is selected.
     * @default false
     */
    selected?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    onClick?: MouseEventHandler<any>;
};
declare const MenuItem: (props: MenuItemProps) => React.JSX.Element;

type MenuListProps = PropsWithChildren & {
    key?: string;
    /**
  * If `true`, will focus the `[role="menu"]` container and move into tab order.
  * @default false
  */
    autoFocus?: boolean;
    /**
     * If `true`, will focus the first menuitem if `variant="menu"` or selected item
     * if `variant="selectedMenu"`.
     * @default false
     */
    autoFocusItem?: boolean;
    /**
     * MenuList contents, normally `MenuItem`s.
     */
    children?: React.ReactNode;
    /**
     * If `true`, will allow focus on disabled items.
     * @default false
     */
    disabledItemsFocusable?: boolean;
    /**
     * If `true`, the menu items will not wrap focus.
     * @default false
     */
    disableListWrap?: boolean;
    /**
     * The variant to use. Use `menu` to prevent selected items from impacting the initial focus
     * and the vertical alignment relative to the anchor element.
     * @default 'selectedMenu'
     */
    variant?: 'menu' | 'selectedMenu';
};
declare const MenuList: (props: MenuListProps) => React.JSX.Element;

type ListProps = PropsWithChildren & {
    key?: string;
    /**
  * The content of the component.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListClasses>;
    /**
     * If `true`, compact vertical padding designed for keyboard and mouse input is used for
     * the list and list items.
     * The prop is available to descendant components as the `dense` context.
     * @default false
     */
    dense?: boolean;
    /**
     * If `true`, vertical padding is removed from the list.
     * @default false
     */
    disablePadding?: boolean;
    /**
     * The content of the subheader, normally `ListSubheader`.
     */
    subheader?: React.ReactNode;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    component?: any;
};
declare const List: (props: ListProps) => React.JSX.Element;

type ListItemProps = PropsWithChildren & {
    key?: React.Key;
    /**
   * Defines the `align-items` style property.
   * @default 'center'
   */
    alignItems?: 'flex-start' | 'center';
    /**
     * If `true`, the list item is focused during the first mount.
     * Focus will also be triggered if the value changes from false to true.
     * @default false
     * @deprecated checkout [ListItemButton](/material-ui/api/list-item-button/) instead
     */
    autoFocus?: boolean;
    /**
     * The content of the component if a `ListItemSecondaryAction` is used it must
     * be the last child.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListItemClasses>;
    /**
     * If `true`, compact vertical padding designed for keyboard and mouse input is used.
     * The prop defaults to the value inherited from the parent List component.
     * @default false
     */
    dense?: boolean;
    /**
     * If `true`, the left and right padding is removed.
     * @default false
     */
    disableGutters?: boolean;
    /**
     * If `true`, all padding is removed.
     * @default false
     */
    disablePadding?: boolean;
    /**
     * If `true`, a 1px light border is added to the bottom of the list item.
     * @default false
     */
    divider?: boolean;
    /**
     * The element to display at the end of ListItem.
     */
    secondaryAction?: React.ReactNode;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
   * The components used for each slot inside.
   *
   * This prop is an alias for the `slots` prop.
   * It's recommended to use the `slots` prop instead.
   *
   * @default {}
   */
    components?: {
        Root?: React.ElementType;
    };
    onClick?: MouseEventHandler<any>;
};
declare const ListItem: (props: ListItemProps) => React.JSX.Element;

type ListItemIconProps = PropsWithChildren & {
    key?: string;
    /**
    * The content of the component, normally `Icon`, `SvgIcon`,
    * or a `@mui/icons-material` SVG icon element.
    */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListItemIconClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const ListItemIcon: (props: ListItemIconProps) => React.JSX.Element;

type ListItemAvatarProps = PropsWithChildren & {
    key?: string;
    /**
  * The content of the component.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListItemAvatarClasses>;
    sx?: SxProps<Theme>;
};
declare const ListItemAvatar: (props: ListItemAvatarProps) => React.JSX.Element;

type ListItemButtonProps = PropsWithChildren & {
    id?: string;
    /**
  * Defines the `align-items` style property.
  * @default 'center'
  */
    alignItems?: 'flex-start' | 'center';
    /**
     * If `true`, the list item is focused during the first mount.
     * Focus will also be triggered if the value changes from false to true.
     * @default false
     */
    autoFocus?: boolean;
    /**
     * The content of the component if a `ListItemSecondaryAction` is used it must
     * be the last child.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListItemButtonClasses>;
    /**
     * If `true`, compact vertical padding designed for keyboard and mouse input is used.
     * The prop defaults to the value inherited from the parent List component.
     * @default false
     */
    dense?: boolean;
    /**
     * If `true`, the component is disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * If `true`, the left and right padding is removed.
     * @default false
     */
    disableGutters?: boolean;
    /**
     * If `true`, a 1px light border is added to the bottom of the list item.
     * @default false
     */
    divider?: boolean;
    /**
     * Use to apply selected styling.
     * @default false
     */
    selected?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    onClick?: MouseEventHandler<any>;
    component?: React.ElementType;
};
declare const ListItemButton: (props: ListItemButtonProps) => React.JSX.Element;

type ListItemSecondaryActionProps = PropsWithChildren & {
    key?: string;
    /**
  * The content of the component.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListItemAvatarClasses>;
    sx?: SxProps<Theme>;
};
declare const ListItemSecondaryAction: (props: ListItemSecondaryActionProps) => React.JSX.Element;

type ListItemTextProps = PropsWithChildren & {
    key?: string;
    /**
   * Alias for the `primary` prop.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListItemTextClasses>;
    /**
     * If `true`, the children won't be wrapped by a Typography component.
     * This can be useful to render an alternative Typography variant by wrapping
     * the `children` (or `primary`) text, and optional `secondary` text
     * with the Typography component.
     * @default false
     */
    disableTypography?: boolean;
    /**
     * If `true`, the children are indented.
     * This should be used if there is no left avatar or left icon.
     * @default false
     */
    inset?: boolean;
    /**
     * The main content element.
     */
    primary?: React.ReactNode;
    /**
     * The secondary content element.
     */
    secondary?: React.ReactNode;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const ListItemText: (props: ListItemTextProps) => React.JSX.Element;

type ListSubheaderProps = PropsWithChildren & {
    key?: string;
    /**
  * The content of the component.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListItemAvatarClasses>;
    /**
   * The color of the component. It supports those theme colors that make sense for this component.
   * @default 'default'
   */
    color?: 'default' | 'primary' | 'inherit';
    /**
     * If `true`, the List Subheader will not have gutters.
     * @default false
     */
    disableGutters?: boolean;
    /**
     * If `true`, the List Subheader will not stick to the top during scroll.
     * @default false
     */
    disableSticky?: boolean;
    /**
     * If `true`, the List Subheader is indented.
     * @default false
     */
    inset?: boolean;
    /**
  * The system prop that allows defining system overrides as well as additional CSS styles.
  */
    sx?: SxProps<Theme>;
};
declare const ListSubheader: (props: ListSubheaderProps) => React.JSX.Element;

declare const Divider: (props: DividerProps) => React.JSX.Element;

type TooltipProps = PropsWithChildren & {
    key?: string;
    /**
    * If `true`, adds an arrow to the tooltip.
    * @default false
    */
    arrow?: boolean;
    /**
     * Tooltip reference element.
     */
    children: React.ReactElement<any, any>;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TooltipClasses>;
    /**
     * The components used for each slot inside.
     *
     * This prop is an alias for the `slots` prop.
     * It's recommended to use the `slots` prop instead.
     *
     * @default {}
     */
    components?: {
        Popper?: React.ElementType<PopperProps>;
        Transition?: React.ElementType;
        Tooltip?: React.ElementType;
        Arrow?: React.ElementType;
    };
    /**
     * The extra props for the slot components.
     * You can override the existing props or add new ones.
     *
     * This prop is an alias for the `slotProps` prop.
     * It's recommended to use the `slotProps` prop instead, as `componentsProps` will be deprecated in the future.
     *
     * @default {}
     */
    componentsProps?: {
        popper?: Partial<PopperProps> & TooltipComponentsPropsOverrides;
        transition?: TransitionProps & TooltipComponentsPropsOverrides;
        tooltip?: React.HTMLProps<HTMLDivElement> & MUIStyledCommonProps & TooltipComponentsPropsOverrides;
        arrow?: React.HTMLProps<HTMLSpanElement> & MUIStyledCommonProps & TooltipComponentsPropsOverrides;
    };
    /**
     * Set to `true` if the `title` acts as an accessible description.
     * By default the `title` acts as an accessible label for the child.
     * @default false
     */
    describeChild?: boolean;
    /**
     * Do not respond to focus-visible events.
     * @default false
     */
    disableFocusListener?: boolean;
    /**
     * Do not respond to hover events.
     * @default false
     */
    disableHoverListener?: boolean;
    /**
     * Makes a tooltip not interactive, i.e. it will close when the user
     * hovers over the tooltip before the `leaveDelay` is expired.
     * @default false
     */
    disableInteractive?: boolean;
    /**
     * Do not respond to long press touch events.
     * @default false
     */
    disableTouchListener?: boolean;
    /**
     * The number of milliseconds to wait before showing the tooltip.
     * This prop won't impact the enter touch delay (`enterTouchDelay`).
     * @default 100
     */
    enterDelay?: number;
    /**
     * The number of milliseconds to wait before showing the tooltip when one was already recently opened.
     * @default 0
     */
    enterNextDelay?: number;
    /**
     * The number of milliseconds a user must touch the element before showing the tooltip.
     * @default 700
     */
    enterTouchDelay?: number;
    /**
     * If `true`, the tooltip follow the cursor over the wrapped element.
     * @default false
     */
    followCursor?: boolean;
    /**
     * This prop is used to help implement the accessibility logic.
     * If you don't provide this prop. It falls back to a randomly generated id.
     */
    id?: string;
    /**
     * The number of milliseconds to wait before hiding the tooltip.
     * This prop won't impact the leave touch delay (`leaveTouchDelay`).
     * @default 0
     */
    leaveDelay?: number;
    /**
     * The number of milliseconds after the user stops touching an element before hiding the tooltip.
     * @default 1500
     */
    leaveTouchDelay?: number;
    /**
     * Callback fired when the component requests to be closed.
     *
     * @param {React.SyntheticEvent} event The event source of the callback.
     */
    onClose?: (event: React.SyntheticEvent | Event) => void;
    /**
     * Callback fired when the component requests to be open.
     *
     * @param {React.SyntheticEvent} event The event source of the callback.
     */
    onOpen?: (event: React.SyntheticEvent) => void;
    /**
     * If `true`, the component is shown.
     */
    open?: boolean;
    /**
     * Tooltip placement.
     * @default 'bottom'
     */
    placement?: 'bottom-end' | 'bottom-start' | 'bottom' | 'left-end' | 'left-start' | 'left' | 'right-end' | 'right-start' | 'right' | 'top-end' | 'top-start' | 'top';
    /**
     * The component used for the popper.
     * @default Popper
     */
    PopperComponent?: React.JSXElementConstructor<PopperProps>;
    /**
     * Props applied to the [`Popper`](/material-ui/api/popper/) element.
     * @default {}
     */
    PopperProps?: Partial<PopperProps>;
    /**
     * The extra props for the slot components.
     * You can override the existing props or add new ones.
     *
     * This prop is an alias for the `componentsProps` prop, which will be deprecated in the future.
     *
     * @default {}
     */
    slotProps?: {
        popper?: Partial<PopperProps> & TooltipComponentsPropsOverrides;
        transition?: TransitionProps & TooltipComponentsPropsOverrides;
        tooltip?: React.HTMLProps<HTMLDivElement> & MUIStyledCommonProps<Theme> & TooltipComponentsPropsOverrides;
        arrow?: React.HTMLProps<HTMLSpanElement> & MUIStyledCommonProps<Theme> & TooltipComponentsPropsOverrides;
    };
    /**
     * The components used for each slot inside.
     *
     * This prop is an alias for the `components` prop, which will be deprecated in the future.
     *
     * @default {}
     */
    slots?: {
        popper?: React.ElementType<PopperProps>;
        transition?: React.ElementType;
        tooltip?: React.ElementType;
        arrow?: React.ElementType;
    };
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * Tooltip title. Zero-length titles string, undefined, null and false are never displayed.
     */
    title: React.ReactNode;
    /**
     * The component used for the transition.
     * [Follow this guide](/material-ui/transitions/#transitioncomponent-prop) to learn more about the requirements for this component.
     * @default Grow
     */
    TransitionComponent?: React.JSXElementConstructor<TransitionProps & {
        children: React.ReactElement<any, any>;
    }>;
    /**
     * Props applied to the transition element.
     * By default, the element is based on this [`Transition`](https://reactcommunity.org/react-transition-group/transition/) component.
     */
    TransitionProps?: TransitionProps;
};
declare const Tooltip: (props: TooltipProps) => React.JSX.Element;

type TableProps = PropsWithChildren & {
    key?: string;
    /**
    * The content of the table, normally `TableHead` and `TableBody`.
    */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableClasses>;
    /**
     * Allows TableCells to inherit padding of the Table.
     * @default 'normal'
     */
    padding?: 'normal' | 'checkbox' | 'none';
    /**
     * Allows TableCells to inherit size of the Table.
     * @default 'medium'
     */
    size?: 'small' | 'medium';
    /**
     * Set the header sticky.
     *
     *  It doesn't work with IE11.
     * @default false
     */
    stickyHeader?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const Table: (props: TableProps) => React.JSX.Element;

type TableBodyProps = PropsWithChildren & {
    key?: string;
    /**
    * The content of the component, normally `TableRow`.
    */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableBodyClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const TableBody: (props: TableBodyProps) => React.JSX.Element;

type TableCellProps = PropsWithChildren & {
    key?: string;
    /**
    * Set the text-align on the table cell content.
    *
    * Monetary or generally number fields **should be right aligned** as that allows
    * you to add them up quickly in your head without having to worry about decimals.
    * @default 'inherit'
    */
    align?: 'inherit' | 'left' | 'center' | 'right' | 'justify';
    /**
     * The content of the component.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableCellClasses>;
    /**
     * The component used for the root node.
     * Either a string to use a HTML element or a component.
     */
    component?: React.ElementType<TableCellBaseProps>;
    /**
     * Sets the padding applied to the cell.
     * The prop defaults to the value (`'default'`) inherited from the parent Table component.
     */
    padding?: 'normal' | 'checkbox' | 'none';
    /**
     * Set scope attribute.
     */
    scope?: TableCellBaseProps['scope'];
    /**
     * Specify the size of the cell.
     * The prop defaults to the value (`'medium'`) inherited from the parent Table component.
     */
    size?: 'small' | 'medium';
    /**
     * Set aria-sort direction.
     */
    sortDirection?: SortDirection;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * Specify the cell type.
     * The prop defaults to the value inherited from the parent TableHead, TableBody, or TableFooter components.
     */
    variant?: 'head' | 'body' | 'footer';
    colSpan?: number;
};
declare const TableCell: (props: TableCellProps) => React.JSX.Element;

type TableContainerProps = PropsWithChildren & {
    key?: string;
    /**
   * The content of the component, normally `Table`.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableContainerClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    component?: React.ElementType;
};
declare const TableContainer: (props: TableContainerProps) => React.JSX.Element;

type TableFooterProps = PropsWithChildren & {
    key?: string;
    /**
    * The content of the component, normally `TableRow`.
    */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableFooterClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const TableFooter: (props: TableFooterProps) => React.JSX.Element;

type TableHeadProps = PropsWithChildren & {
    key?: string;
    /**
  * The content of the component, normally `TableRow`.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableHeadClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const TableHead: (props: TableHeadProps) => React.JSX.Element;

type TableRowProps = PropsWithChildren & {
    key?: React.Key;
    /**
  * Should be valid `<tr>` children such as `TableCell`.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableRowClasses>;
    /**
     * If `true`, the table row will shade on hover.
     * @default false
     */
    hover?: boolean;
    /**
     * If `true`, the table row will have the selected shading.
     * @default false
     */
    selected?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    onClick?: MouseEventHandler<any>;
};
declare const TableRow: (props: TableRowProps) => React.JSX.Element;

type TableSortLabelProps = PropsWithChildren & {
    key?: string;
    /**
    * If `true`, the label will have the active styling (should be true for the sorted column).
    * @default false
    */
    active?: boolean;
    /**
     * Label contents, the arrow will be appended automatically.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableSortLabelClasses>;
    /**
     * The current sort direction.
     * @default 'asc'
     */
    direction?: 'asc' | 'desc';
    /**
     * Hide sort icon when active is false.
     * @default false
     */
    hideSortIcon?: boolean;
    /**
     * Sort icon to use.
     * @default ArrowDownwardIcon
     */
    IconComponent?: React.JSXElementConstructor<{
        className: string;
    }>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    onClick?: MouseEventHandler<any>;
};
declare const TableSortLabel: (props: TableSortLabelProps) => React.JSX.Element;

type TablePaginationProps = PropsWithChildren & {
    key?: string;
    /**
    * The component used for displaying the actions.
    * Either a string to use a HTML element or a component.
    * @default TablePaginationActions
    */
    ActionsComponent?: React.ElementType<TablePaginationActionsProps>;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TablePaginationClasses>;
    /**
     * The total number of rows.
     *
     * To enable server side pagination for an unknown number of items, provide -1.
     */
    count: number;
    /**
     * If `true`, the component is disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * Accepts a function which returns a string value that provides a user-friendly name for the current page.
     * This is important for screen reader users.
     *
     * For localization purposes, you can use the provided [translations](/material-ui/guides/localization/).
     * @param {string} type The link or button type to format ('first' | 'last' | 'next' | 'previous').
     * @returns {string}
     * @default function defaultGetAriaLabel(type) {
     *   return `Go to ${type} page`;
     * }
     */
    getItemAriaLabel?: (type: 'first' | 'last' | 'next' | 'previous') => string;
    /**
     * Customize the displayed rows label. Invoked with a `{ from, to, count, page }`
     * object.
     *
     * For localization purposes, you can use the provided [translations](/material-ui/guides/localization/).
     * @default function defaultLabelDisplayedRows({ from, to, count }) {
     *   return `${from}�${to} of ${count !== -1 ? count : `more than ${to}`}`;
     * }
     */
    labelDisplayedRows?: (paginationInfo: LabelDisplayedRowsArgs) => React.ReactNode;
    /**
     * Customize the rows per page label.
     *
     * For localization purposes, you can use the provided [translations](/material-ui/guides/localization/).
     * @default 'Rows per page:'
     */
    labelRowsPerPage?: React.ReactNode;
    /**
     * Callback fired when the page is changed.
     *
     * @param {React.MouseEvent<HTMLButtonElement> | null} event The event source of the callback.
     * @param {number} page The page selected.
     */
    onPageChange: (event: React.MouseEvent<HTMLButtonElement> | null, page: number) => void;
    /**
     * Callback fired when the number of rows per page is changed.
     *
     * @param {React.ChangeEvent<HTMLTextAreaElement | HTMLInputElement>} event The event source of the callback.
     */
    onRowsPerPageChange?: React.ChangeEventHandler<HTMLTextAreaElement | HTMLInputElement>;
    /**
     * The zero-based index of the current page.
     */
    page: number;
    /**
     * The number of rows per page.
     *
     * Set -1 to display all the rows.
     */
    rowsPerPage: number;
    /**
     * Customizes the options of the rows per page select field. If less than two options are
     * available, no select field will be displayed.
     * Use -1 for the value with a custom label to show all the rows.
     * @default [10, 25, 50, 100]
     */
    rowsPerPageOptions?: ReadonlyArray<number | {
        value: number;
        label: string;
    }>;
    /**
     * If `true`, show the first-page button.
     * @default false
     */
    showFirstButton?: boolean;
    /**
     * If `true`, show the last-page button.
     * @default false
     */
    showLastButton?: boolean;
    /**
     * The props used for each slot inside the TablePagination.
     * @default {}
     */
    slotProps?: {
        actions?: TablePaginationActionsProps['slotProps'];
        select?: Partial<SelectProps>;
    };
    /**
     * The components used for each slot inside the TablePagination.
     * Either a string to use a HTML element or a component.
     * @default {}
     */
    slots?: {
        actions?: TablePaginationActionsProps['slots'];
    };
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    component?: React.ElementType;
};
declare const TablePagination: (props: TablePaginationProps) => React.JSX.Element;

declare const Grid: (props: GridProps$1) => React.JSX.Element;

type GridProps = PropsWithChildren & {
    key?: string;
    /**
     * The content of the component.
     */
    children?: React.ReactNode;
    /**
     * The number of columns.
     * @default 12
     */
    columns?: ResponsiveStyleValue<number>;
    /**
     * Defines the horizontal space between the type `item` components.
     * It overrides the value of the `spacing` prop.
     */
    columnSpacing?: ResponsiveStyleValue<GridSpacing>;
    /**
     * If `true`, the component will have the flex *container* behavior.
     * You should be wrapping *items* with a *container*.
     * @default false
     */
    container?: boolean;
    /**
     * Defines the `flex-direction` style property.
     * It is applied for all screen sizes.
     * @default 'row'
     */
    direction?: ResponsiveStyleValue<GridDirection>;
    /**
     * If `true`, the negative margin and padding are apply only to the top and left sides of the grid.
     */
    disableEqualOverflow?: boolean;
    /**
     * @internal
     * The level of the grid starts from `0`
     * and increases when the grid nests inside another grid regardless of container or item.
     *
     * ```js
     * <Grid> // level 0
     *   <Grid> // level 1
     *     <Grid> // level 2
     *   <Grid> // level 1
     * ```
     *
     * Only consecutive grid is considered nesting.
     * A grid container will start at `0` if there are non-Grid element above it.
     *
     * ```js
     * <Grid> // level 0
     *   <div>
     *     <Grid> // level 0
     *       <Grid> // level 1
     * ```
     */
    unstable_level?: number;
    /**
     * Defines the vertical space between the type `item` components.
     * It overrides the value of the `spacing` prop.
     */
    rowSpacing?: ResponsiveStyleValue<GridSpacing>;
    /**
     * Defines the space between the type `item` components.
     * It can only be used on a type `container` component.
     * @default 0
     */
    spacing?: ResponsiveStyleValue<GridSpacing> | undefined;
    /**
     * Defines the `flex-wrap` style property.
     * It's applied for all screen sizes.
     * @default 'wrap'
     */
    wrap?: GridWrap;
    /**
    * If a number, it sets the number of columns the grid item uses.
    * It can't be greater than the total number of columns of the container (12 by default).
    * If 'auto', the grid item's width matches its content.
    * If false, the prop is ignored.
    * If true, the grid item's width grows to use the space available in the grid container.
    * The value is applied for the `lg` breakpoint and wider screens if not overridden.
    * @default false
    */
    lg?: boolean | GridSize;
    /**
     * If a number, it sets the margin-left equals to the number of columns the grid item uses.
     * If 'auto', the grid item push itself to the right-end of the container.
     * The value is applied for the `lg` breakpoint and wider screens if not overridden.
     */
    lgOffset?: GridSize;
    /**
     * If a number, it sets the number of columns the grid item uses.
     * It can't be greater than the total number of columns of the container (12 by default).
     * If 'auto', the grid item's width matches its content.
     * If false, the prop is ignored.
     * If true, the grid item's width grows to use the space available in the grid container.
     * The value is applied for the `md` breakpoint and wider screens if not overridden.
     * @default false
     */
    md?: boolean | GridSize;
    /**
     * If a number, it sets the margin-left equals to the number of columns the grid item uses.
     * If 'auto', the grid item push itself to the right-end of the container.
     * The value is applied for the `md` breakpoint and wider screens if not overridden.
     */
    mdOffset?: GridSize;
    /**
     * If a number, it sets the number of columns the grid item uses.
     * It can't be greater than the total number of columns of the container (12 by default).
     * If 'auto', the grid item's width matches its content.
     * If false, the prop is ignored.
     * If true, the grid item's width grows to use the space available in the grid container.
     * The value is applied for the `sm` breakpoint and wider screens if not overridden.
     * @default false
     */
    sm?: boolean | GridSize;
    /**
     * If a number, it sets the margin-left equals to the number of columns the grid item uses.
     * If 'auto', the grid item push itself to the right-end of the container.
     * The value is applied for the `sm` breakpoint and wider screens if not overridden.
     */
    smOffset?: GridSize;
    /**
     * If a number, it sets the number of columns the grid item uses.
     * It can't be greater than the total number of columns of the container (12 by default).
     * If 'auto', the grid item's width matches its content.
     * If false, the prop is ignored.
     * If true, the grid item's width grows to use the space available in the grid container.
     * The value is applied for the `xl` breakpoint and wider screens if not overridden.
     * @default false
     */
    xl?: boolean | GridSize;
    /**
     * If a number, it sets the margin-left equals to the number of columns the grid item uses.
     * If 'auto', the grid item push itself to the right-end of the container.
     * The value is applied for the `xl` breakpoint and wider screens if not overridden.
     */
    xlOffset?: GridSize;
    /**
     * If a number, it sets the number of columns the grid item uses.
     * It can't be greater than the total number of columns of the container (12 by default).
     * If 'auto', the grid item's width matches its content.
     * If false, the prop is ignored.
     * If true, the grid item's width grows to use the space available in the grid container.
     * The value is applied for all the screen sizes with the lowest priority.
     * @default false
     */
    xs?: boolean | GridSize;
    /**
     * If a number, it sets the margin-left equals to the number of columns the grid item uses.
     * If 'auto', the grid item push itself to the right-end of the container.
     * The value is applied for the `xs` breakpoint and wider screens if not overridden.
     */
    xsOffset?: GridSize;
    component?: React.ElementType;
};
declare const Grid2: (props: GridProps) => React.JSX.Element;

declare const Drawer: (props: DrawerProps) => React.JSX.Element;

type SwipeableDrawerProps = PropsWithChildren & {
    key?: string;
    /**
   * If set to true, the swipe event will open the drawer even if the user begins the swipe on one of the drawer's children.
   * This can be useful in scenarios where the drawer is partially visible.
   * You can customize it further with a callback that determines which children the user can drag over to open the drawer
   * (for example, to ignore other elements that handle touch move events, like sliders).
   *
   * @param {TouchEvent} event The 'touchstart' event
   * @param {HTMLDivElement} swipeArea The swipe area element
   * @param {HTMLDivElement} paper The drawer's paper element
   *
   * @default false
   */
    allowSwipeInChildren?: boolean | ((e: TouchEvent, swipeArea: HTMLDivElement, paper: HTMLDivElement) => boolean);
    /**
     * Disable the backdrop transition.
     * This can improve the FPS on low-end devices.
     * @default false
     */
    disableBackdropTransition?: boolean;
    /**
     * If `true`, touching the screen near the edge of the drawer will not slide in the drawer a bit
     * to promote accidental discovery of the swipe gesture.
     * @default false
     */
    disableDiscovery?: boolean;
    /**
     * If `true`, swipe to open is disabled. This is useful in browsers where swiping triggers
     * navigation actions. Swipe to open is disabled on iOS browsers by default.
     * @default typeof navigator !== 'undefined' && /iPad|iPhone|iPod/.test(navigator.userAgent)
     */
    disableSwipeToOpen?: boolean;
    /**
     * Affects how far the drawer must be opened/closed to change its state.
     * Specified as percent (0-1) of the width of the drawer
     * @default 0.52
     */
    hysteresis?: number;
    /**
     * Defines, from which (average) velocity on, the swipe is
     * defined as complete although hysteresis isn't reached.
     * Good threshold is between 250 - 1000 px/s
     * @default 450
     */
    minFlingVelocity?: number;
    /**
     * Callback fired when the component requests to be closed.
     *
     * @param {React.SyntheticEvent<{}>} event The event source of the callback.
     */
    onClose: React.ReactEventHandler<{}>;
    /**
     * Callback fired when the component requests to be opened.
     *
     * @param {React.SyntheticEvent<{}>} event The event source of the callback.
     */
    onOpen: React.ReactEventHandler<{}>;
    /**
     * If `true`, the component is shown.
     * @default false
     */
    open?: boolean;
    /**
     * The element is used to intercept the touch events on the edge.
     */
    SwipeAreaProps?: object;
    /**
     * The width of the left most (or right most) area in `px` that
     * the drawer can be swiped open from.
     * @default 20
     */
    swipeAreaWidth?: number;
    anchor?: "left" | "right" | "top" | "bottom" | undefined;
};
declare const SwipeableDrawer: (props: SwipeableDrawerProps) => React.JSX.Element;

type StepperProps = PropsWithChildren & {
    key?: string;
    /**
   * Set the active step (zero based index).
   * Set to -1 to disable all the steps.
   * @default 0
   */
    activeStep?: number;
    /**
     * If set to 'true' and orientation is horizontal,
     * then the step label will be positioned under the icon.
     * @default false
     */
    alternativeLabel?: boolean;
    /**
     * Two or more `<Step />` components.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<StepperClasses>;
    /**
     * An element to be placed between each step.
     * @default <StepConnector />
     */
    connector?: React.ReactElement<any, any> | null;
    /**
     * If set the `Stepper` will not assist in controlling steps for linear flow.
     * @default false
     */
    nonLinear?: boolean;
    /**
     * The component orientation (layout flow direction).
     * @default 'horizontal'
     */
    orientation?: Orientation;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const Stepper: (props: StepperProps) => React.JSX.Element;

type TabsProps$1 = PropsWithChildren & {
    key?: string;
    /**
   * Callback fired when the component mounts.
   * This is useful when you want to trigger an action programmatically.
   * It supports two actions: `updateIndicator()` and `updateScrollButtons()`
   *
   * @param {object} actions This object contains all possible actions
   * that can be triggered programmatically.
   */
    action?: React.Ref<TabsActions>;
    /**
     * If `true`, the scroll buttons aren't forced hidden on mobile.
     * By default the scroll buttons are hidden on mobile and takes precedence over `scrollButtons`.
     * @default false
     */
    allowScrollButtonsMobile?: boolean;
    /**
     * The label for the Tabs as a string.
     */
    'aria-label'?: string;
    /**
     * An id or list of ids separated by a space that label the Tabs.
     */
    'aria-labelledby'?: string;
    /**
     * If `true`, the tabs are centered.
     * This prop is intended for large views.
     * @default false
     */
    centered?: boolean;
    /**
     * The content of the component.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TabsClasses>;
    /**
     * The components used for each slot inside.
     * @default {}
     */
    slots?: {
        StartScrollButtonIcon?: React.ElementType;
        EndScrollButtonIcon?: React.ElementType;
    };
    /**
     * The extra props for the slot components.
     * You can override the existing props or add new ones.
     * @default {}
     */
    /**
     * Determines the color of the indicator.
     * @default 'primary'
     */
    indicatorColor?: 'secondary' | 'primary';
    /**
     * Callback fired when the value changes.
     *
     * @param {React.SyntheticEvent} event The event source of the callback. **Warning**: This is a generic event not a change event.
     * @param {any} value We default to the index of the child (number)
     */
    onChange?: (event: React.SyntheticEvent, value: any) => void;
    /**
     * The component orientation (layout flow direction).
     * @default 'horizontal'
     */
    orientation?: 'horizontal' | 'vertical';
    /**
     * The component used to render the scroll buttons.
     * @default TabScrollButton
     */
    ScrollButtonComponent?: React.ElementType;
    /**
     * Determine behavior of scroll buttons when tabs are set to scroll:
     *
     * - `auto` will only present them when not all the items are visible.
     * - `true` will always present them.
     * - `false` will never present them.
     *
     * By default the scroll buttons are hidden on mobile.
     * This behavior can be disabled with `allowScrollButtonsMobile`.
     * @default 'auto'
     */
    scrollButtons?: 'auto' | true | false;
    /**
     * If `true` the selected tab changes on focus. Otherwise it only
     * changes on activation.
     */
    selectionFollowsFocus?: boolean;
    /**
     * Props applied to the tab indicator element.
     * @default  {}
     */
    TabIndicatorProps?: React.HTMLAttributes<HTMLDivElement> & {
        sx?: SxProps<Theme>;
    };
    /**
     * Props applied to the [`TabScrollButton`](/material-ui/api/tab-scroll-button/) element.
     * @default {}
     */
    TabScrollButtonProps?: Partial<TabScrollButtonProps>;
    /**
     * Determines the color of the `Tab`.
     * @default 'primary'
     */
    textColor?: 'secondary' | 'primary' | 'inherit';
    /**
     * The value of the currently selected `Tab`.
     * If you don't want any selected `Tab`, you can set this prop to `false`.
     */
    value?: any;
    /**
     *  Determines additional display behavior of the tabs:
     *
     *  - `scrollable` will invoke scrolling properties and allow for horizontally
     *  scrolling (or swiping) of the tab bar.
     *  - `fullWidth` will make the tabs grow to use all the available space,
     *  which should be used for small views, like on mobile.
     *  - `standard` will render the default state.
     * @default 'standard'
     */
    variant?: 'standard' | 'scrollable' | 'fullWidth';
    /**
     * If `true`, the scrollbar is visible. It can be useful when displaying
     * a long vertical list of tabs.
     * @default false
     */
    visibleScrollbar?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const Tabs: (props: TabsProps$1) => React.JSX.Element;

type TabProps = PropsWithChildren & {
    key?: string;
    /**
    * This prop isn't supported.
    * Use the `component` prop if you need to change the children structure.
    */
    children?: null;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TabClasses>;
    /**
     * If `true`, the component is disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * If `true`, the  keyboard focus ripple is disabled.
     * @default false
     */
    disableFocusRipple?: boolean;
    /**
     * The icon to display.
     */
    icon?: string | React.ReactElement;
    /**
     * The position of the icon relative to the label.
     * @default 'top'
     */
    iconPosition?: 'top' | 'bottom' | 'start' | 'end';
    /**
     * The label element.
     */
    label?: React.ReactNode;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * You can provide your own value. Otherwise, we fallback to the child position index.
     */
    value?: any;
    /**
     * Tab labels appear in a single row.
     * They can use a second line if needed.
     * @default false
     */
    wrapped?: boolean;
};
declare const Tab: (props: TabProps) => React.JSX.Element;

type StepProps$1 = PropsWithChildren & {
    key?: string;
    /**
     * Sets the step as active. Is passed to child components.
     */
    active?: boolean;
    /**
     * Should be `Step` sub-components such as `StepLabel`, `StepContent`.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<StepClasses>;
    /**
     * Mark the step as completed. Is passed to child components.
     */
    completed?: boolean;
    /**
     * If `true`, the step is disabled, will also disable the button if
     * `StepButton` is a child of `Step`. Is passed to child components.
     */
    disabled?: boolean;
    /**
     * Expand the step.
     * @default false
     */
    expanded?: boolean;
    /**
     * The position of the step.
     * The prop defaults to the value inherited from the parent Stepper component.
     */
    index?: number;
    /**
     * If `true`, the Step is displayed as rendered last.
     * The prop defaults to the value inherited from the parent Stepper component.
     */
    last?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const Step: (props: StepProps$1) => React.JSX.Element;

type StepProps = PropsWithChildren & {
    key?: string;
    /**
   * Can be a `StepLabel` or a node to place inside `StepLabel` as children.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<StepButtonClasses>;
    /**
     * The icon displayed by the step label.
     */
    icon?: React.ReactNode;
    /**
     * The optional node to display.
     */
    optional?: React.ReactNode;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const StepButton: (props: StepProps) => React.JSX.Element;

type StepLabelProps = PropsWithChildren & {
    key?: string;
    /**
    * In most cases will simply be a string containing a title for the label.
    */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<StepLabelClasses>;
    /**
     * The props used for each slot inside.
     * @default {}
     */
    componentsProps?: {
        /**
         * Props applied to the label element.
         * @default {}
         */
        label?: React.HTMLProps<HTMLSpanElement>;
    };
    /**
     * If `true`, the step is marked as failed.
     * @default false
     */
    error?: boolean;
    /**
     * Override the default label of the step icon.
     */
    icon?: React.ReactNode;
    /**
     * The optional node to display.
     */
    optional?: React.ReactNode;
    /**
     * The props used for each slot inside.
     * @default {}
     */
    slotProps?: {
        /**
         * Props applied to the label element.
         * @default {}
         */
        label?: React.HTMLProps<HTMLSpanElement>;
    };
    /**
     * The component to render in place of the [`StepIcon`](/material-ui/api/step-icon/).
     */
    StepIconComponent?: React.ElementType<StepIconProps>;
    /**
     * Props applied to the [`StepIcon`](/material-ui/api/step-icon/) element.
     */
    StepIconProps?: Partial<StepIconProps>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const StepLabel: (props: StepLabelProps) => React.JSX.Element;

type StepContentProps = PropsWithChildren & {
    key?: string;
    /**
   * The content of the component.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<StepContentClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The component used for the transition.
     * [Follow this guide](/material-ui/transitions/#transitioncomponent-prop) to learn more about the requirements for this component.
     * @default Collapse
     */
    TransitionComponent?: React.JSXElementConstructor<TransitionProps & {
        children: React.ReactElement<any, any>;
    }>;
    /**
     * Adjust the duration of the content expand transition.
     * Passed as a prop to the transition component.
     *
     * Set to 'auto' to automatically calculate transition time based on height.
     * @default 'auto'
     */
    transitionDuration?: TransitionProps['timeout'] | 'auto';
    /**
     * Props applied to the transition element.
     * By default, the element is based on this [`Transition`](https://reactcommunity.org/react-transition-group/transition/) component.
     */
    TransitionProps?: TransitionProps;
};
declare const StepContent: (props: StepContentProps) => React.JSX.Element;

type TabsProps = PropsWithChildren & {
    key?: string;
    /**
    * Set the text-align on the component.
    * @default 'inherit'
    */
    align?: 'inherit' | 'left' | 'center' | 'right' | 'justify';
    /**
     * The content of the component.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TypographyClasses>;
    /**
     * If `true`, the text will have a bottom margin.
     * @default false
     */
    gutterBottom?: boolean;
    /**
     * If `true`, the text will not wrap, but instead will truncate with a text overflow ellipsis.
     *
     * Note that text overflow can only happen with block or inline-block level elements
     * (the element needs to have a width in order to overflow).
     * @default false
     */
    noWrap?: boolean;
    /**
     * If `true`, the element will be a paragraph element.
     * @default false
     */
    paragraph?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * Applies the theme typography styles.
     * @default 'body1'
     */
    variant?: OverridableStringUnion<Variant | 'inherit', TypographyPropsVariantOverrides>;
    /**
     * The component maps the variant prop to a range of different HTML element types.
     * For instance, subtitle1 to `<h6>`.
     * If you wish to change that mapping, you can provide your own.
     * Alternatively, you can use the `component` prop.
     * @default {
     *   h1: 'h1',
     *   h2: 'h2',
     *   h3: 'h3',
     *   h4: 'h4',
     *   h5: 'h5',
     *   h6: 'h6',
     *   subtitle1: 'h6',
     *   subtitle2: 'h6',
     *   body1: 'p',
     *   body2: 'p',
     *   inherit: 'p',
     * }
     */
    variantMapping?: Partial<Record<OverridableStringUnion<Variant | 'inherit', TypographyPropsVariantOverrides>, string>>;
    color?: string;
    component?: React.ElementType;
    display?: any;
};
declare const Typography: (props: TabsProps) => React.JSX.Element;

declare const Accordion: (props: AccordionProps) => React.JSX.Element;

declare const AccordionDetails: (props: AccordionDetailsProps) => React.JSX.Element;

declare const AccordionSummary: (props: AccordionSummaryProps) => React.JSX.Element;

declare const Card: (props: CardProps) => React.JSX.Element;

declare const CardActions: (props: CardActionsProps) => React.JSX.Element;

declare const CardContent: (props: CardContentProps) => React.JSX.Element;

type LinkProps = PropsWithChildren & {
    key?: string;
    /**
   * The content of the component.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<LinkClasses>;
    /**
     * The color of the link.
     * @default 'primary'
     */
    color?: TypographyOwnProps['color'];
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * `classes` prop applied to the [`Typography`](/material-ui/api/typography/) element.
     */
    TypographyClasses?: TypographyOwnProps['classes'];
    /**
     * Controls when the link should have an underline.
     * @default 'always'
     */
    underline?: 'none' | 'hover' | 'always';
    /**
     * Applies the theme typography styles.
     * @default 'inherit'
     */
    variant?: TypographyOwnProps['variant'];
    href?: string;
};
declare const Link: (props: LinkProps) => React.JSX.Element;

declare const AppBar: (props: AppBarProps) => React.JSX.Element;

declare const Alert: (props: AlertProps) => React.JSX.Element;

declare const AlertTitle: (props: AlertTitleProps) => React.JSX.Element;

declare const Backdrop: (props: BackdropProps) => React.JSX.Element;

declare const Dialog: (props: DialogProps) => React.JSX.Element;

declare const DialogActions: (props: DialogActionsProps) => React.JSX.Element;

declare const DialogContent: (props: DialogContentProps) => React.JSX.Element;

declare const DialogContentText: (props: DialogContentTextProps) => React.JSX.Element;

declare const DialogTitle: (props: DialogTitleProps) => React.JSX.Element;

declare const Chip: (props: ChipProps) => React.JSX.Element;

declare const Box: (props: BoxProps) => React.JSX.Element;

type ToolbarProps = PropsWithChildren & {
    key?: string;
    /**
  * The Toolbar children, usually a mixture of `IconButton`, `Button` and `Typography`.
  * The Toolbar is a flex container, allowing flex item properties to be used to lay out the children.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ToolbarClasses>;
    /**
     * If `true`, disables gutter padding.
     * @default false
     */
    disableGutters?: boolean;
    /**
     * The variant to use.
     * @default 'regular'
     */
    variant?: OverridableStringUnion<'regular' | 'dense', ToolbarPropsVariantOverrides>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    component?: React.ElementType;
};
declare const Toolbar: (props: ToolbarProps) => React.JSX.Element;

type PaperProps = PropsWithChildren & {
    key?: string;
    /**
   * The content of the component.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<PaperClasses>;
    /**
     * Shadow depth, corresponds to `dp` in the spec.
     * It accepts values between 0 and 24 inclusive.
     * @default 1
     */
    elevation?: number;
    /**
     * If `true`, rounded corners are disabled.
     * @default false
     */
    square?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The variant to use.
     * @default 'elevation'
     */
    variant?: OverridableStringUnion<'elevation' | 'outlined', PaperPropsVariantOverrides>;
};
declare const Paper: (props: PaperProps) => React.JSX.Element;

declare const FormGroup: (props: FormGroupProps) => React.JSX.Element;

declare const FormControl: (props: FormControlProps) => React.JSX.Element;

declare const FormControlLabel: (props: FormControlLabelProps) => React.JSX.Element;

declare const FormHelperText: (props: FormHelperTextProps) => React.JSX.Element;

declare const FormLabel: (props: FormLabelProps) => React.JSX.Element;

type CircularProgressProps = PropsWithChildren & {
    key?: string;
    /**
    * Override or extend the styles applied to the component.
    */
    classes?: Partial<CircularProgressClasses>;
    /**
     * The color of the component.
     * It supports both default and custom theme colors, which can be added as shown in the
     * [palette customization guide](https://mui.com/material-ui/customization/palette/#custom-colors).
     * @default 'primary'
     */
    color?: OverridableStringUnion<'primary' | 'secondary' | 'error' | 'info' | 'success' | 'warning' | 'inherit', CircularProgressPropsColorOverrides>;
    /**
     * If `true`, the shrink animation is disabled.
     * This only works if variant is `indeterminate`.
     * @default false
     */
    disableShrink?: boolean;
    /**
     * The size of the component.
     * If using a number, the pixel unit is assumed.
     * If using a string, you need to provide the CSS unit, for example '3rem'.
     * @default 40
     */
    size?: number | string;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The thickness of the circle.
     * @default 3.6
     */
    thickness?: number;
    /**
     * The value of the progress indicator for the determinate variant.
     * Value between 0 and 100.
     * @default 0
     */
    value?: number;
    /**
     * The variant to use.
     * Use indeterminate when there is no progress value.
     * @default 'indeterminate'
     */
    variant?: 'determinate' | 'indeterminate';
};
declare const CircularProgress: (props: CircularProgressProps) => React.JSX.Element;

type LinearProgressProps = PropsWithChildren & {
    key?: string;
    /**
   * Override or extend the styles applied to the component.
   */
    classes?: Partial<LinearProgressClasses>;
    /**
     * The color of the component.
     * It supports both default and custom theme colors, which can be added as shown in the
     * [palette customization guide](https://mui.com/material-ui/customization/palette/#custom-colors).
     * @default 'primary'
     */
    color?: OverridableStringUnion<'primary' | 'secondary' | 'error' | 'info' | 'success' | 'warning' | 'inherit', LinearProgressPropsColorOverrides>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The value of the progress indicator for the determinate and buffer variants.
     * Value between 0 and 100.
     */
    value?: number;
    /**
     * The value for the buffer variant.
     * Value between 0 and 100.
     */
    valueBuffer?: number;
    /**
     * The variant to use.
     * Use indeterminate or query when there is no progress value.
     * @default 'indeterminate'
     */
    variant?: 'determinate' | 'indeterminate' | 'buffer' | 'query';
};
declare const LinearProgress: (props: LinearProgressProps) => React.JSX.Element;

type StackProps = PropsWithChildren & {
    key?: string;
    /**
    * The content of the component.
    */
    children?: React.ReactNode;
    /**
     * Defines the `flex-direction` style property.
     * It is applied for all screen sizes.
     * @default 'column'
     */
    direction?: ResponsiveStyleValue<'row' | 'row-reverse' | 'column' | 'column-reverse'>;
    /**
     * Defines the space between immediate children.
     * @default 0
     */
    spacing?: ResponsiveStyleValue<number | string>;
    /**
     * Add an element between each child.
     */
    divider?: React.ReactNode;
    /**
     * If `true`, the CSS flexbox `gap` is used instead of applying `margin` to children.
     *
     * While CSS `gap` removes the [known limitations](https://mui.com/joy-ui/react-stack/#limitations),
     * it is not fully supported in some browsers. We recommend checking https://caniuse.com/?search=flex%20gap before using this flag.
     *
     * To enable this flag globally, follow the [theme's default props](https://mui.com/material-ui/customization/theme-components/#default-props) configuration.
     * @default false
     */
    useFlexGap?: boolean;
    /**
     * The system prop, which allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps$1<Theme$1>;
};
declare const Stack: (props: StackProps) => React.JSX.Element;

type IconNames = keyof typeof Icons;
type IconProps = {
    iconName: IconNames;
};
declare const Icon: FC<IconProps>;

declare const Autocomplete: <Value, Multiple extends boolean | undefined = false, DisableClearable extends boolean | undefined = false, FreeSolo extends boolean | undefined = false, ChipComponent extends React.ElementType<any, keyof React.JSX.IntrinsicElements> = "div">(props: AutocompleteProps<Value, Multiple, DisableClearable, FreeSolo, ChipComponent>) => JSX.Element;

declare const LoadingButton: (props: LoadingButtonProps) => JSX.Element;

declare const IconButton: (props: IconButtonProps) => JSX.Element;

declare const FileButton: (props: ButtonProps) => JSX.Element;

declare const ButtonGroup: (props: ButtonGroupProps) => React.JSX.Element;

declare const Checkbox: (props: CheckboxProps) => JSX.Element;

declare const FloatingButton: (props: FabProps) => React.JSX.Element;

declare const Radio: (props: RadioProps) => JSX.Element;

declare const RadioGroup: (props: RadioGroupProps) => JSX.Element;

declare const Rating: (props: RatingProps) => JSX.Element;

declare const Select: (props: SelectProps$1) => JSX.Element;

declare const Switch: (props: SwitchProps) => JSX.Element;

declare const Slider: (props: SliderProps) => JSX.Element;

declare const TextField: (props: TextFieldProps) => JSX.Element;

declare const InputAdornment: (props: InputAdornmentProps) => JSX.Element;

declare const OutlinedInput: (props: OutlinedInputProps) => JSX.Element;

declare const ToggleButton: (props: ToggleButtonProps) => React.JSX.Element;

declare const ToggleButtonGroup: (props: ToggleButtonGroupProps) => React.JSX.Element;

export { Accordion, AccordionDetails, AccordionSummary, Alert, AlertTitle, AppBar, Autocomplete, Avatar, AvatarGroup, Backdrop, Badge, Box, ButtonGroup, Card, CardActions, CardContent, Checkbox, Chip, CircularProgress, Dialog, DialogActions, DialogContent, DialogContentText, DialogTitle, Divider, Drawer, FileButton, FloatingButton, FormControl, FormControlLabel, FormGroup, FormHelperText, FormLabel, Grid, Grid2, Icon, IconButton, InputAdornment, LinearProgress, Link, List, ListItem, ListItemAvatar, ListItemButton, ListItemIcon, ListItemSecondaryAction, ListItemText, ListSubheader, LoadingButton, Menu, MenuItem, MenuList, OutlinedInput, Paper, Radio, RadioGroup, Rating, Select, Slider, Stack, Step, StepButton, StepContent, StepLabel, Stepper, SwipeableDrawer, Switch, Tab, Table, TableBody, TableCell, TableContainer, TableFooter, TableHead, TablePagination, TableRow, TableSortLabel, Tabs, TextField, ToggleButton, ToggleButtonGroup, Toolbar, Tooltip, Typography };
